#!/usr/bin/env python

import numpy as np
from matplotlib import animation
from matplotlib import pyplot as plt
from matplotlib.backends.qt_compat import QtWidgets
from matplotlib.widgets import Slider
from scipy.special import jn, jn_zeros

π = np.pi

r = np.linspace(0., 1., 201)
φ = np.linspace(0., 2.*π, 721)
rr, φφ = np.meshgrid(r, φ)


def modes(m, n):
    z = jn_zeros(m, n)[-1]
    res = jn(m, z * rr) * np.cos(m * φφ)
    res /= np.max(np.abs(res.ravel()))
    return res


fig = plt.figure(figsize=(16, 9))
ax = fig.add_subplot(111, polar='True')
manager = fig.canvas.manager
manager.window.findChild(QtWidgets.QToolBar).setVisible(False)
manager.set_window_title("Mody RP")
manager.full_screen_toggle()
ax.axis('off')

psi = modes(0, 1)

img = ax.pcolormesh(φφ, rr, psi, cmap='bwr', vmin=-1, vmax=1)
ax.grid(False)

φ = np.linspace(0, 2*π, 3601)
ax.plot(φ, np.ones_like(φ), 'k', linewidth=1)

# ax.set_aspect('equal')
# ax.xaxis.set_major_locator(plt.MultipleLocator(1.00))
# ax.yaxis.set_major_locator(plt.MultipleLocator(1.00))
# ax.tick_params(axis='both', which='both', direction="in", left=True, right=True, top=True, bottom=True)
ax.xaxis.set_major_formatter(plt.NullFormatter())
ax.yaxis.set_major_formatter(plt.NullFormatter())

# ax.set_xlim(0, 2)
# ax.set_ylim(0, 2)

fig.tight_layout()

mmax = fig.add_axes([0.90, 0.10, 0.03, 0.8])
mnax = fig.add_axes([0.95, 0.10, 0.03, 0.8])

sst = {
    'track_color': '0.7',
    'color': '0.7',
    'initcolor': 'k',
}

m_slider = Slider(ax=mmax, label='$m$', orientation='vertical', valmin=0, valmax=12, valinit=0, valstep=1, **sst)
n_slider = Slider(ax=mnax, label='$n$', orientation='vertical', valmin=0, valmax=12, valinit=1, valstep=1, **sst)

def on_slider(val):
    global psi
    psi = modes(m_slider.val, n_slider.val)
    img.set_array(psi)
    fig.canvas.draw_idle()


m_slider.on_changed(on_slider)
n_slider.on_changed(on_slider)

plt.show()
